<?php
/**
 * Plugin Name: EDD Software Licensing Version Quick Edit
 * Plugin URI: https://wordpress.org/plugins/edd-software-licensing-quick-edit-version/
 * Description: Easily edit a Software Licensing enabled EDD product via quick edit.
 * Author: Rich Tabor
 * Author URI: https://richtabor.com
 * Version: 1.0.0
 * Text Domain: 'edd-software-licensing-quick-edit-version'
 * Domain Path: languages
 * Requires at least: 4.0
 * Tested up to: 4.9
 *
 * This plugin is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 *
 * EDD Software Licensing Version Quick Edit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EDD Software Licensing Version Quick Edit. If not, see <http://www.gnu.org/licenses/>.
 *
 * @package   EDD Software Licensing Version Quick Edit
 * @author  Rich Tabor of ThemeBeans <hello@themebeans.com>
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU Public License
 * @version   1.0.2
 */

/**
 * Remove these actions, as we're overriding them.
 */
function eddslquickedit_remove_actions() {
	remove_action( 'quick_edit_custom_box', 'edd_price_field_quick_edit', 10, 2 );
	remove_action( 'bulk_edit_custom_box', 'edd_price_field_quick_edit', 10, 2 );
	remove_action( 'manage_posts_custom_column', 'edd_sl_render_download_columns', 10, 2 );
}
add_action( 'init', 'eddslquickedit_remove_actions' );

/**
 * Load script on the downloads admin page.
 */
function eddslquickedit_admin_scripts() {

	$screen	  = get_current_screen();
	$screen_id	= $screen ? $screen->id : '';

	// Only enqueue admin scripts on relevant pages.
	if ( 'edit-download' !== $screen_id ) {
		return;
	}

	// Location.
	$js_dir = plugin_dir_url( __FILE__ ) . 'assets/js/';

	// Use minified libraries if SCRIPT_DEBUG is turned off.
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '';

	wp_enqueue_script( 'edd-software-licensing-version-quick-edit', $js_dir . 'edd-software-licensing-version-quick-edit' . esc_attr( $suffix ) . '.js', array( 'jquery', 'jquery-form', 'inline-edit-post' ), '1.0.0', false );
}
add_action( 'admin_enqueue_scripts', 'eddslquickedit_admin_scripts' );

/**
 * Replaces the price field, and adds price + version, to Quick Edit options.
 *
 * @since 1.1.3.4
 * @param string|string $column_name Name of the column.
 * @param string|string $post_type Current Post Type (i.e. download).
 * @return void
 */
function eddslquick_price_and_version_field_quick_edit( $column_name, $post_type ) {

	// Return early if this function does not exist.
	if ( ! function_exists( 'edd_get_label_singular' ) ) {
		return;
	}

	// Make sure we're in the right column.
	if ( 'price' !== $column_name || 'download' !== $post_type ) {
		return;
	} ?>

	<fieldset class="inline-edit-col-left">
		<div id="edd-download-data" class="inline-edit-col">
			<h4><?php echo esc_html( sprintf( __( '%s Configuration', 'edd-sl-version-quick-edit' ), edd_get_label_singular() ) ); ?></h4>
			<label>
				<span class="title"><?php esc_html_e( 'Price', 'edd-software-licensing-version-quick-edit' ); ?></span>
				<span class="input-text-wrap">
					<input type="text" name="_edd_regprice" class="text regprice" />
				</span>
			</label>
			<label>
				<span class="title"><?php esc_html_e( 'Version', 'edd-software-licensing-version-quick-edit' ); ?></span>
				<span class="input-text-wrap">
					<input type="text" name="_edd_regversion" class="text regversion" />
				</span>
			</label>
			<br class="clear" />
		</div>
	</fieldset>
	<?php
}
add_action( 'quick_edit_custom_box', 'eddslquick_price_and_version_field_quick_edit', 10, 2 );

/**
 * Updates price when saving post
 *
 * @since 1.0.0
 * @param int|int $post_id Download (Post) ID.
 * @return void
 */
function eddslquickedit_version_save_quick_edit( $post_id ) {

	if ( ! isset( $_POST['post_type'] ) || 'download' !== $_POST['post_type'] ) {
		return;
	}

	if ( ! current_user_can( 'edit_post', $post_id ) ) {
		return $post_id;
	}

	if ( defined( 'DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
		return $post_id;
	}

	if ( isset( $_REQUEST['_edd_regversion'] ) ) {
		update_post_meta( $post_id, '_edd_sl_version', strip_tags( stripslashes( $_REQUEST['_edd_regversion'] ) ) );
	}
}
add_action( 'save_post', 'eddslquickedit_version_save_quick_edit' );

/**
 * Render Download Columns (from Software Licensing).
 * I just added a hidden input field to capture the value of the version.
 *
 * @since 1.0.0
 * @param string|string $column_name Column name.
 * @param int|int       $post_id Download (Post) ID.
 * @return void
 */
function eddslquickedit_sl_render_download_columns( $column_name, $post_id ) {

	if ( 'download' === get_post_type( $post_id ) ) {
		switch ( $column_name ) {
			case 'version':
				echo esc_html( get_post_meta( $post_id, '_edd_sl_version', true ) );
				echo '<input type="hidden" class="downloadversion-' . esc_attr( $post_id ) . '" value="' . esc_attr( get_post_meta( $post_id, '_edd_sl_version', true ) ) . '" />';
				break;
		}
	}
}

add_action( 'manage_posts_custom_column', 'eddslquickedit_sl_render_download_columns', 99, 2 );
